==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/db/repl/storage_interface.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/client.h"
#include "mongo/db/operation_context.h"
#include "mongo/db/repl/storage_interface.h"
#include "mongo/db/service_context.h"
#include "mongo/util/str.h"

namespace mongo {
namespace repl {


namespace {
const auto getStorageInterface =
    ServiceContext::declareDecoration<std::unique_ptr<StorageInterface>>();
}

StorageInterface* StorageInterface::get(ServiceContext* service) {
    return getStorageInterface(service).get();
}

StorageInterface* StorageInterface::get(ServiceContext& service) {
    return getStorageInterface(service).get();
}

StorageInterface* StorageInterface::get(OperationContext* opCtx) {
    return get(opCtx->getClient()->getServiceContext());
}

void StorageInterface::set(ServiceContext* service, std::unique_ptr<StorageInterface> storage) {
    auto& storageInterface = getStorageInterface(service);
    storageInterface = std::move(storage);
}

}  // namespace repl
}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/repl/storage_interface.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include <utility>

#include "mongo/db/client.h"
#include "mongo/db/operation_context.h"
#include "mongo/db/repl/storage_interface.h"
#include "mongo/db/service_context.h"
#include "mongo/util/decorable.h"

namespace mongo {
namespace repl {


namespace {
const auto getStorageInterface =
    ServiceContext::declareDecoration<std::unique_ptr<StorageInterface>>();
}

StorageInterface* StorageInterface::get(ServiceContext* service) {
    return getStorageInterface(service).get();
}

StorageInterface* StorageInterface::get(ServiceContext& service) {
    return getStorageInterface(service).get();
}

StorageInterface* StorageInterface::get(OperationContext* opCtx) {
    return get(opCtx->getClient()->getServiceContext());
}

void StorageInterface::set(ServiceContext* service, std::unique_ptr<StorageInterface> storage) {
    auto& storageInterface = getStorageInterface(service);
    storageInterface = std::move(storage);
}

}  // namespace repl
}  // namespace mongo
